<?php
/*
Plugin Name: WooCommerce Hide Product EasyToolsWP
Description: Adds a checkbox in Quick Edit to hide products from archives.
Version: 1.2
Author: EasyToolsWP.com
Author URI: https://www.easytoolswp.com
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

// Add the checkbox to Quick Edit
function wc_quick_edit_custom_box($column_name, $post_type) {
    if ($post_type == 'product' && $column_name == 'price') {
        ?>
        <fieldset class="inline-edit-col-right">
            <div class="inline-edit-col">
                <label class="alignleft">
                    <input type="checkbox" name="hide_product" value="yes">
                    <span class="checkbox-title"><?php _e('Hide product', 'woocommerce'); ?></span>
                </label>
            </div>
        </fieldset>
        <?php
    }
}
add_action('quick_edit_custom_box', 'wc_quick_edit_custom_box', 10, 2);

// Enqueue the script to handle the quick edit checkbox state
function wc_quick_edit_enqueue_scripts() {
    ?>
    <script type="text/javascript">
    jQuery(function($) {
        var $wp_inline_edit = inlineEditPost.edit;
        inlineEditPost.edit = function(id) {
            $wp_inline_edit.apply(this, arguments);

            var post_id = 0;
            if (typeof(id) == 'object') {
                post_id = parseInt(this.getId(id));
            }

            if (post_id > 0) {
                var $edit_row = $('#edit-' + post_id);
                var $post_row = $('#post-' + post_id);

                var hide_product = $post_row.find('.column-hide_product input[type="hidden"]').val();
                $edit_row.find('input[name="hide_product"]').prop('checked', hide_product === 'yes');
            }
        };
    });
    </script>
    <?php
}
add_action('admin_footer', 'wc_quick_edit_enqueue_scripts');

// Save the checkbox value
function wc_save_quick_edit_data($post_id) {
    if (isset($_POST['hide_product'])) {
        update_post_meta($post_id, '_hide_product', 'yes');
    } else {
        update_post_meta($post_id, '_hide_product', 'no');
    }
}
add_action('save_post', 'wc_save_quick_edit_data');

// Hide products from archives if checkbox is checked
function wc_hide_product_from_archives($query) {
    if (!is_admin() && $query->is_main_query() && (is_shop() || is_product_category() || is_product_tag() || is_home())) {
        $meta_query = $query->get('meta_query');

        if (!is_array($meta_query)) {
            $meta_query = array();
        }

        $meta_query[] = array(
            'relation' => 'OR',
            array(
                'key'     => '_hide_product',
                'value'   => 'yes',
                'compare' => 'NOT LIKE'
            ),
            array(
                'key'     => '_hide_product',
                'compare' => 'NOT EXISTS'
            )
        );

        $query->set('meta_query', $meta_query);
    }
}
add_action('pre_get_posts', 'wc_hide_product_from_archives');

// Add hidden field value to quick edit
function wc_quick_edit_hidden_fields($actions, $post) {
    if ($post->post_type == 'product') {
        $hide_product = get_post_meta($post->ID, '_hide_product', true);
        $hide_product = $hide_product == 'yes' ? 'yes' : 'no';
        ?>
        <script type="text/javascript">
            document.addEventListener('DOMContentLoaded', function() {
                var hideProduct = '<?php echo esc_js($hide_product); ?>';
                var row = document.querySelector('#post-<?php echo $post->ID; ?>');
                if (row) {
                    var quickEdit = row.querySelector('.inline-edit-row');
                    if (quickEdit) {
                        var checkbox = quickEdit.querySelector('input[name="hide_product"]');
                        if (checkbox) {
                            checkbox.checked = hideProduct === 'yes';
                        }
                    }
                }
            });
        </script>
        <div class="hidden column-hide_product">
            <input type="hidden" value="<?php echo esc_attr($hide_product); ?>" />
        </div>
        <?php
    }
    return $actions;
}
add_filter('post_row_actions', 'wc_quick_edit_hidden_fields', 10, 2);